@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2012 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: envManager.php 4832 2012-04-10 16:22:46Z fishbone $
+ * @version    SVN: $Id: envManager.php 4875 2012-04-21 13:40:40Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once(M3_SYSTEM_INCLUDE_PATH . '/common/version.php');	// システムバージョンクラス
@@ -1688,14 +1688,14 @@ class EnvManager extends Core
 	/**
 	 * 現在のページID、サブページIDのURLを作成
 	 *
+	 * @param bool          $withPageSubId		ページサブIDを付加するかどうか
 	 * @return string		作成したURL
 	 */
-	public function createCurrentPageUrl()
+	public function createCurrentPageUrl($withPageSubId = true)
 	{
-		//return $this->getCurrentScriptUrl() . '?sub=' . $this->getCurrentPageSubId();
-		
 		$url = $this->createPageUrl();
-		return $url . '?sub=' . $this->getCurrentPageSubId();
+		if ($withPageSubId) $url .= '?sub=' . $this->getCurrentPageSubId();
+		return $url;
 	}
 	/**
 	 * 指定ページIDのURLを作成
