@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2012 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: imageManager.php 4660 2012-02-05 07:02:55Z fishbone $
+ * @version    SVN: $Id: imageManager.php 4703 2012-02-19 15:00:19Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once(M3_SYSTEM_INCLUDE_PATH . '/common/core.php');
@@ -195,88 +195,5 @@ class ImageManager extends Core
 		$ret = imagedestroy($thumbObj);
 		return $ret;
 	}
-	/**
-	 * サムネールを作成
-	 *
-	 * @param string $path		ファイルパス
-	 * @param int $type			画像タイプ
-	 * @param string $destPath	出力ファイル保存のパス
-	 * @param int $destType		出力画像タイプ
-	 * @param int $size			サムネールの縦横サイズ
-	 * @return bool				true=成功、false=失敗
-	 */
-/*	function createThumbImage($path, $type, $destPath, $destType, $size)
-	{
-		// 画像作成
-		switch ($type){
-			case IMAGETYPE_GIF:
-				$image = @imagecreatefromgif($path);
-				break;
-			case IMAGETYPE_JPEG:
-				$image = @imagecreatefromjpeg($path);
-				break;
-			case IMAGETYPE_PNG:
-				$image = @imagecreatefrompng($path);
-				break;
-			default:
-				return false;
-		}
-
-		// 画像サイズ取得
-		$width = imagesx($image);
-		$height = imagesy($image);
-
-		if ($width > $height){
-			$n_height = $height * ($size / $width);
-			$n_width = $size;
-		} else {
-			$n_width = $width * ($size / $height);
-			$n_height = $size;
-		}
-		
-		$x = 0;
-		$y = 0;
-		if ($n_width < $size) $x = round(($size - $n_width) / 2);
-		if ($n_height < $size) $y = round(($size - $n_height) / 2);
-		
-		// サムネールの背景色を取得
-		$bgColor = self::$_configArray[photo_mainCommonDef::CF_THUMBNAIL_BG_COLOR];	// サムネール背景色
-		$bgColorR = intval(substr($bgColor, 1, 2), 16);
-		$bgColorG = intval(substr($bgColor, 3, 2), 16);
-		$bgColorB = intval(substr($bgColor, 5, 2), 16);
-
-		// TrueColorイメージを作成
-		$thumb = imagecreatetruecolor($size, $size);
-		//$bgcolor = imagecolorallocate($thumb, 255, 255, 255);		// 背景色設定
-		$bgcolor = imagecolorallocate($thumb, $bgColorR, $bgColorG, $bgColorB);		// 背景色設定
-		imagefill($thumb, 0, 0, $bgcolor);
-		
-		// 画像リサイズ
-		// imagecopyresampledの方がimagecopyresizedよりも画質が良いのでこちらを使用
-		if (function_exists("imagecopyresampled")){
-			if (!imagecopyresampled($thumb, $image, $x, $y, 0, 0, $n_width, $n_height, $width, $height)){
-				if (!imagecopyresized($thumb, $image, $x, $y, 0, 0, $n_width, $n_height, $width, $height)) return false;
-			}
-		} else {
-			if (!imagecopyresized($thumb, $image, $x, $y, 0, 0, $n_width, $n_height, $width, $height)) return false;
-		}
-
-		// 画像出力
-		switch ($destType){
-			case IMAGETYPE_GIF:
-				$ret = @imagegif($thumb, $destPath, self::IMAGE_QUALITY);
-				break;
-			case IMAGETYPE_JPEG:
-				$ret = @imagejpeg($thumb, $destPath, self::IMAGE_QUALITY);
-				break;
-			case IMAGETYPE_PNG:
-				$ret = @imagepng($thumb, $destPath, self::IMAGE_QUALITY);
-				break;
-		}
-		// イメージを破棄
-		$ret = imagedestroy($image);
-		$ret = imagedestroy($thumb);
-		return $ret;
-	}*/
 }
 ?>
