@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2010 Magic3 Project.
+ * @copyright  Copyright 2006-2011 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_mainPagedefWidgetContainer.php 3866 2010-11-29 09:02:05Z fishbone $
+ * @version    SVN: $Id: admin_mainPagedefWidgetContainer.php 4319 2011-09-13 23:41:08Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseAdminWidgetContainer.php');
@@ -464,13 +464,11 @@ class admin_mainPagedefWidgetContainer extends BaseAdminWidgetContainer
 		$value = $this->convertToDispString($pid);
 		
 		// 表示ラベルを作成
-		$private = '';			// 公開状態
-		if (!$fetchedRow['pg_active']) $private = '[' . $this->_('Unpublished') . ']';			// 非公開
-		$name = $value . $private . ' - ' . $this->convertToDispString($fetchedRow['pg_name']);
-		// デフォルトのページサブIDのときは、説明を付加
-		if ($pid == $this->defaultPageSubId){
-			$name .= '[' . $this->_('Default') . ']';			// デフォルト値
-		}
+		$name = $value;
+		if ($pid == $this->defaultPageSubId) $name .= '[' . $this->_('Default') . ']';			// デフォルトのページサブIDのときは、説明を付加
+		if (!$fetchedRow['pg_active']) $name .= '[' . $this->_('Unpublished') . ']';			// 非公開
+		$name .= ' - ' . $this->convertToDispString($fetchedRow['pg_name']);
+		
 		$row = array(
 			'value'    => $value,			// ページID
 			'name'     => $name,			// ページ名
