@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2010 Magic3 Project.
+ * @copyright  Copyright 2006-2012 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_mainSmenudefWidgetContainer.php 4569 2012-01-05 03:18:23Z fishbone $
+ * @version    SVN: $Id: admin_mainSmenudefWidgetContainer.php 4814 2012-04-01 01:19:15Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/admin_mainBaseWidgetContainer.php');
@@ -29,12 +29,15 @@ class admin_mainSmenudefWidgetContainer extends admin_mainBaseWidgetContainer
 	private $isExistsMenuItem;		// メニュー項目が存在するかどうか
 	private $isExistsPreviewMenuItem;		// プレビューメニュー項目が存在するかどうか
 	private $itemTypeArray;		// メニュー項目の種類
+	private $menuHtml;	// コンテンツメニュー
 	const MAIN_MENU_ID = 'main_menu';			// メインメニューID
-	const CONTENT_WIDGET_ID = 'default_content';			// コンテンツ編集ウィジェット
 	const WIDGET_TYPE_MENU = 'menu';		// メニュー型のウィジェット(キャッシュクリア用)
 	const CONTENT_TYPE_PC = '';			// 汎用コンテンツのコンテンツタイプ(PC用)
 	const CONTENT_TYPE_MOBILE = 'mobile';			// 汎用コンテンツのコンテンツタイプ(携帯用)
 	const CONTENT_TYPE_SMARTPHONE = 'smartphone';			// 汎用コンテンツのコンテンツタイプ(スマートフォン用)
+	const CONTENT_WIDGET_ID_PC = 'default_content';			// コンテンツ編集ウィジェット(PC用)
+	const CONTENT_WIDGET_ID_MOBILE = 'm/content';			// コンテンツ編集ウィジェット(携帯用)
+	const CONTENT_WIDGET_ID_SMARTPHONE = 's/content';			// コンテンツ編集ウィジェット(スマートフォン用)
 	
 	/**
 	 * コンストラクタ
@@ -179,6 +182,20 @@ class admin_mainSmenudefWidgetContainer extends admin_mainBaseWidgetContainer
 		$ret = $this->db->getMenuId($this->menuId, $row);
 		if ($ret) $this->menuDeviceType = $row['mn_device_type'];
 		
+		// コンテンツタイプを取得
+		switch ($this->menuDeviceType){
+			case 0:			// PC用
+			default:
+				$contType = self::CONTENT_TYPE_PC;			// 汎用コンテンツのコンテンツタイプ
+				break;
+			case 1:			// 携帯用
+				$contType = self::CONTENT_TYPE_MOBILE;			// 汎用コンテンツのコンテンツタイプ
+				break;
+			case 2:			// スマートフォン用
+				$contType = self::CONTENT_TYPE_SMARTPHONE;			// 汎用コンテンツのコンテンツタイプ
+				break;
+		}
+		
 		$act = $request->trimValueOf('act');
 		if ($act == 'updatemenu'){		// メニュー項目順の更新のとき
 			$menuitems = $request->trimValueOf('menuitems');
@@ -226,8 +243,22 @@ class admin_mainSmenudefWidgetContainer extends admin_mainBaseWidgetContainer
 		if (!$this->isExistsPreviewMenuItem) $this->tmpl->setAttribute('menuitemlist', 'visibility', 'hidden');// メニュープレビュー
 		if ($fixedMode == '1') $this->tmpl->addVar("_widget", "sel_menu_id_disabled", 'disabled');			// メニューIDの選択可否
 		
+		// コンテンツ編集用ウィジェット
+		switch ($contType){
+			case self::CONTENT_TYPE_PC:			// PC用
+			default:
+				$contentEditWidget = self::CONTENT_WIDGET_ID_PC;
+				break;
+			case self::CONTENT_TYPE_MOBILE:			// 携帯用
+				$contentEditWidget = self::CONTENT_WIDGET_ID_MOBILE;
+				break;
+			case self::CONTENT_TYPE_SMARTPHONE:			// スマートフォン用
+				$contentEditWidget = self::CONTENT_WIDGET_ID_SMARTPHONE;
+				break;
+		}
+	
 		$this->tmpl->addVar("_widget", "serial_list", implode($this->serialArray, ','));// 表示項目のシリアル番号を設定
-		$this->tmpl->addVar('_widget', 'content_widget_id', self::CONTENT_WIDGET_ID);// コンテンツ表示ウィジェット
+		$this->tmpl->addVar('_widget', 'content_widget_id', $contentEditWidget);// コンテンツ表示ウィジェット
 		$this->tmpl->addVar('_widget', 'admin_url', $this->getUrl($this->gEnv->getDefaultAdminUrl()));// 管理者URL
 		$this->tmpl->addVar("_widget", "fixed_mode", $fixedMode);		// メニュー定義IDが固定かどうか
 	}
@@ -265,6 +296,20 @@ class admin_mainSmenudefWidgetContainer extends admin_mainBaseWidgetContainer
 		$ret = $this->db->getMenuId($this->menuId, $row);
 		if ($ret) $this->menuDeviceType = $row['mn_device_type'];
 		
+		// コンテンツタイプを取得
+		switch ($this->menuDeviceType){
+			case 0:			// PC用
+			default:
+				$contType = self::CONTENT_TYPE_PC;			// 汎用コンテンツのコンテンツタイプ
+				break;
+			case 1:			// 携帯用
+				$contType = self::CONTENT_TYPE_MOBILE;			// 汎用コンテンツのコンテンツタイプ
+				break;
+			case 2:			// スマートフォン用
+				$contType = self::CONTENT_TYPE_SMARTPHONE;			// 汎用コンテンツのコンテンツタイプ
+				break;
+		}
+
 		$reloadData = false;		// データの再読み込み
 		if ($act == 'add'){// 新規追加
 			// 入力チェック
@@ -353,6 +398,18 @@ class admin_mainSmenudefWidgetContainer extends admin_mainBaseWidgetContainer
 				$url = $this->gEnv->getDefaultUrl() . '?' . M3_REQUEST_PARAM_PAGE_SUB_ID . '=' . $this->currentPageSubId;
 				if (!empty($this->contentId)) $url .= '&' . M3_REQUEST_PARAM_CONTENT_ID . '=' . $this->contentId;
 			}
+		} else if ($act == 'getmenu'){		// コンテンツ選択メニュー取得
+			// コンテンツIDを取得
+			$contentSerial = $request->trimValueOf('content_serial');
+			$ret = $this->db->getContentBySerial($contentSerial, $row);
+			if ($ret) $this->contentId = $row['cn_id'];
+			
+			// コンテンツ選択メニューを作成
+			$this->menuHtml  = '<select name="item_content_id" onchange="selectPage();">';
+	        $this->menuHtml .= '<option value="">-- 未選択 --</option>';
+			$this->db->getAllContents($langId, $contType, array($this, 'contentListLoop'));
+			$this->menuHtml .= '</select>';
+			$this->gInstance->getAjaxManager()->addData('menu_html', $this->menuHtml);
 		} else {
 			$reloadData = true;		// データの再読み込み
 		}
@@ -395,7 +452,6 @@ class admin_mainSmenudefWidgetContainer extends admin_mainBaseWidgetContainer
 		$url = str_replace(M3_TAG_START . M3_TAG_MACRO_ROOT_URL . M3_TAG_END, $this->gEnv->getRootUrl(), $url);		// マクロ展開
 
 		$contentType = '';		// コンテンツタイプ(ページ属性)
-		$contType = '';			// 汎用コンテンツのコンテンツタイプ
 		if ($this->currentPageSubId == '_root'){
 			$this->tmpl->setAttribute('input_no_url', 'visibility', 'visible');// URL非表示データ
 			$this->tmpl->addVar('_widget', 'root_selected', 'selected');		// ページサブID選択
@@ -417,20 +473,16 @@ class admin_mainSmenudefWidgetContainer extends admin_mainBaseWidgetContainer
 				}
 
 				// メニューの端末タイプごとのアクセスポイントを取得
-				// 汎用コンテンツのコンテンツタイプを取得
 				switch ($this->menuDeviceType){
 					case 0:			// PC用
 					default:
 						$url = $this->gEnv->getDefaultUrl();
-						$contType = self::CONTENT_TYPE_PC;			// 汎用コンテンツのコンテンツタイプ
 						break;
 					case 1:			// 携帯用
 						$url = $this->gEnv->getDefaultMobileUrl();
-						$contType = self::CONTENT_TYPE_MOBILE;			// 汎用コンテンツのコンテンツタイプ
 						break;
 					case 2:			// スマートフォン用
 						$url = $this->gEnv->getDefaultSmartphoneUrl();
-						$contType = self::CONTENT_TYPE_SMARTPHONE;			// 汎用コンテンツのコンテンツタイプ
 						break;
 				}
 				
@@ -456,7 +508,7 @@ class admin_mainSmenudefWidgetContainer extends admin_mainBaseWidgetContainer
 		switch ($contentType){
 			case M3_VIEW_TYPE_CONTENT:				// 汎用コンテンツ
 				$this->tmpl->setAttribute('sel_content', 'visibility', 'visible');// コンテンツ選択メニュー表示
-				$this->db->getVisibleAllContents($langId, $contType, array($this, 'contentListLoop'));
+				$this->db->getAllContents($langId, $contType, array($this, 'contentListLoop'));
 				break;
 			case M3_VIEW_TYPE_PRODUCT:				// 製品
 				break;
@@ -494,6 +546,20 @@ class admin_mainSmenudefWidgetContainer extends admin_mainBaseWidgetContainer
 		// メニューID選択メニュー作成
 		$this->db->getAllMenuItems($this->menuId, array($this, 'menuIdLoop'));
 		
+		// コンテンツ編集用ウィジェット
+		switch ($contType){
+			case self::CONTENT_TYPE_PC:			// PC用
+			default:
+				$contentEditWidget = self::CONTENT_WIDGET_ID_PC;
+				break;
+			case self::CONTENT_TYPE_MOBILE:			// 携帯用
+				$contentEditWidget = self::CONTENT_WIDGET_ID_MOBILE;
+				break;
+			case self::CONTENT_TYPE_SMARTPHONE:			// スマートフォン用
+				$contentEditWidget = self::CONTENT_WIDGET_ID_SMARTPHONE;
+				break;
+		}
+		
 		// ### 入力値を再設定 ###
 		$this->tmpl->addVar("_widget", "sel_item_name", $name);		// 名前
 		$this->tmpl->addVar("_widget", "desc", $desc);		// 説明
@@ -503,7 +569,7 @@ class admin_mainSmenudefWidgetContainer extends admin_mainBaseWidgetContainer
 		$attrStr = '';
 		if (!empty($contentType)) $attrStr = $this->_('Page Attribute:') . ' ' . $contentType;		// ページ属性：
 		$this->tmpl->addVar("_widget", "attr", $attrStr);		// ページ属性
-		
+		$this->tmpl->addVar('_widget', 'content_widget_id', $contentEditWidget);// コンテンツ表示ウィジェット
 		// リンクタイプ
 		switch ($linkType){
 			case 0:			// 同ウィンドウで開くリンク
@@ -683,15 +749,19 @@ class admin_mainSmenudefWidgetContainer extends admin_mainBaseWidgetContainer
 	 */
 	function contentListLoop($index, $fetchedRow, $param)
 	{
+		$id = $fetchedRow['cn_id'];
 		$selected = '';
-		if ($fetchedRow['cn_id'] == $this->contentId) $selected = 'selected';	// 現在のコンテンツID
+		if ($id == $this->contentId) $selected = 'selected';	// 現在のコンテンツID
 		$row = array(
-			'value'    => $this->convertToDispString($fetchedRow['cn_id']),			// ページID
-			'name'     => $this->convertToDispString($fetchedRow['cn_name']),			// ページ名
+			'value'    => $this->convertToDispString($id),								// コンテンツID
+			'name'     => $this->convertToDispString($fetchedRow['cn_name']),			// コンテンツ名
 			'selected' => $selected														// 選択中かどうか
 		);
 		$this->tmpl->addVars('content_list', $row);
 		$this->tmpl->parseTemplate('content_list', 'a');
+		
+		// コンテンツ選択メニューHTML
+		$this->menuHtml .= '<option value="' . $id . '" ' . $selected . '>' . $this->convertToDispString($fetchedRow['cn_name']) . '</option>';
 		return true;
 	}
 	/**
