@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_mainTestWidgetContainer.php 4657 2012-02-03 14:58:00Z fishbone $
+ * @version    SVN: $Id: admin_mainTestWidgetContainer.php 4830 2012-04-06 01:59:03Z fishbone $
  * @link       http://www.magic3.org
  */
 //require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/admin_mainBaseWidgetContainer.php');
@@ -58,8 +58,7 @@ class admin_mainTestWidgetContainer extends admin_mainBaseWidgetContainer
 	 */
 	function _assign($request, &$param)
 	{
-	$ret = $this->gInstance->getImageManager()->createDefaultThumb(M3_VIEW_TYPE_PHOTO, '123', '/var/www/html/magic3/resource/image/1.jpg');
-	echo 'OK...';
+	//$ret = $this->gInstance->getImageManager()->createDefaultThumb(M3_VIEW_TYPE_PHOTO, '123', '/var/www/html/magic3/resource/image/1.jpg');
 /*
 		// 契約番号(8桁) オンライン登録時に発行された契約番号を入力してください。
 		$contract_code = "48346400";
