@@ -11,7 +11,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: index.php 4152 2011-05-25 14:31:16Z fishbone $
+ * @version    SVN: $Id: index.php 4321 2011-09-14 22:20:49Z fishbone $
  * @link       http://www.magic3.org
  */
 // 直接アクセスの防止
@@ -187,6 +187,8 @@ $HELP['opelog_message']['title'] = 'メッセージ';
 $HELP['opelog_message']['body'] = 'ログメッセージを示します。';
 $HELP['opelog_message_detail']['title'] = 'メッセージ詳細';
 $HELP['opelog_message_detail']['body'] = '詳細なログメッセージを示します。';
+$HELP['opelog_message_code']['title'] = 'メッセージコード';
+$HELP['opelog_message_code']['body'] = 'ログメッセージの識別コードです。';
 $HELP['opelog_ip']['title'] = 'IP';
 $HELP['opelog_ip']['body'] = '処理を実行したクライアントのIPを示します。';
 $HELP['opelog_access_log']['title'] = 'アクセスログ番号';
