@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2011 Magic3 Project.
+ * @copyright  Copyright 2006-2012 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_menu3WidgetContainer.php 4222 2011-07-02 01:01:19Z fishbone $
+ * @version    SVN: $Id: admin_menu3WidgetContainer.php 4828 2012-04-05 14:22:29Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseAdminWidgetContainer.php');
@@ -29,6 +29,7 @@ class admin_menu3WidgetContainer extends BaseAdminWidgetContainer
 	const THEME_CSS_FILE = 'jquery-ui.custom.css';		// テーマファイル
 //	const CF_ADMIN_DEFAULT_THEME = 'admin_default_theme';		// 管理画面用jQueryUIテーマ
 	const HELP_ICON_FILE = '/images/system/help24.gif';		// ヘルプアイコン
+	const CLOSE_ICON_FILE = '/images/system/close32.png';		// ウィンドウ閉じるアイコン
 	const MAX_SITENAME_LENGTH = 20;		// サイト名の最大文字数
 	const ICON_SIZE = 24;			// アイコンサイズ
 	const HELP_TITLE = 'ヘルプ';
@@ -102,6 +103,10 @@ class admin_menu3WidgetContainer extends BaseAdminWidgetContainer
 			if ($openBy != 'tabs'){		// タブ表示以外
 				$this->tmpl->setAttribute('closebutton', 'visibility', 'visible');
 			
+				// ウィンドウ閉じるアイコンを設定
+				$iconUrl = $this->gEnv->getRootUrl() . self::CLOSE_ICON_FILE;
+				$this->tmpl->addVar("closebutton", "close_image", $this->getUrl($iconUrl));
+				
 				// サーバ指定されている場合はサーバ名を設定
 				$server = $request->trimValueOf(M3_REQUEST_PARAM_SERVER);
 				if (!empty($server)){
