@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2010 Magic3 Project.
+ * @copyright  Copyright 2006-2012 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: default_menuWidgetContainer.php 4844 2012-04-12 06:07:55Z fishbone $
+ * @version    SVN: $Id: default_menuWidgetContainer.php 4896 2012-05-01 05:22:52Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
@@ -134,14 +134,25 @@ class default_menuWidgetContainer extends BaseWidgetContainer
 				$classArray = array();
 				$linkClassArray = array();
 				$attr = '';
-				// Joomla用メニューデータ
-				$addMenuItem = true;			// メニュー項目を追加するかどうか
+				// Joomla用メニューデータ(デフォルト値)
 				$menuItem = new stdClass;		// Joomla用メニューデータ
 				$menuItem->type = 'alias';		// 内部リンク。外部リンク(url)
 				$menuItem->id = $index + 1;
 				$menuItem->level = $level + 1;
 				$menuItem->active = false;
-				
+				$menuItem->parent = false;
+				// 階層作成用
+				$menuItem->deeper = false;
+				$menuItem->shallower = false;
+				$menuItem->level_diff = 0;
+				$menuTreeCount = count($this->menuTree);
+				if ($menuTreeCount > 0){		// 前データがあるときは取得
+					$menuLastItem = $this->menuTree[$menuTreeCount -1];
+					$menuLastItem->deeper = ($menuItem->level > $menuLastItem->level);
+					$menuLastItem->shallower = ($menuItem->level < $menuLastItem->level);
+					$menuLastItem->level_diff = $menuLastItem->level - $menuItem->level;
+				}
+									
 				// 非表示のときは処理を飛ばす
 				if (!$row['md_visible']) continue;
 				
@@ -191,26 +202,37 @@ class default_menuWidgetContainer extends BaseWidgetContainer
 				$name = $row['md_name'];
 				if (empty($name)) continue;
 				
+				$index++;		// インデックス番号更新
+								
 				switch ($row['md_type']){
 					case 0:			// リンク項目のとき
-						if (count($classArray) > 0) $attr .= ' class="' . implode(' ', $classArray) . '"';
-						$treeHtml .= '<li' . $attr . '><a href="' . $this->convertUrlToHtmlEntity($linkUrl) . '" ' . $linkOption . '><span>' . $this->convertToDispString($name) . '</span></a></li>' . M3_NL;
 						// Joomla用メニューデータ作成
-						$addMenuItem = true;			// メニュー項目を追加するかどうか
 						$menuItem->title = $name;
 						$menuItem->flink = $linkUrl;
-						$menuItem->parent = false;
+						
+						// ##### Joomla用メニュー階層更新 #####
+						$this->menuTree[] = $menuItem;
+						
+						// ##### タグ作成 #####
+						if (count($classArray) > 0) $attr .= ' class="' . implode(' ', $classArray) . '"';
+						$treeHtml .= '<li' . $attr . '><a href="' . $this->convertUrlToHtmlEntity($linkUrl) . '" ' . $linkOption . '><span>' . $this->convertToDispString($name) . '</span></a></li>' . M3_NL;
 						break;
 					case 1:			// フォルダのとき
 						if (!empty($this->isHierMenu)){	// 階層化メニューを使用する場合
 							// Joomla用メニューデータ作成
-							$addMenuItem = true;			// メニュー項目を追加するかどうか
 							$menuItem->title = $name;
 							$menuItem->flink = $linkUrl;
 							$menuItem->parent = true;
+							// 階層作成用
+							//$menuItem->deeper = true;
+							//$menuItem->level_diff = 1;
 
+							// ##### Joomla用メニュー階層更新 #####
+							$this->menuTree[] = $menuItem;
+						
 							// 階層を更新
-							array_push($parentTree, $index + 1);
+							//array_push($parentTree, $index + 1);
+							array_push($parentTree, $index);
 							
 							// サブメニュー作成
 							$menuText = $this->createMenu($menuId, $row['md_id'], $level + 1, $hasSelectedChild, $parentTree);
@@ -224,7 +246,7 @@ class default_menuWidgetContainer extends BaseWidgetContainer
 							// 先頭に「parent」クラスを追加
 							array_unshift($classArray, 'parent');
 							
-							// 子項目を追加
+							// ##### タグ作成 #####
 							if (count($classArray) > 0) $attr .= ' class="' . implode(' ', $classArray) . '"';
 							$treeHtml .= '<li' . $attr . '><a href="' . $this->convertUrlToHtmlEntity($linkUrl) . '"><span>' . $this->convertToDispString($name) . '</span></a>' . M3_NL;
 							if (!empty($menuText)){
@@ -239,17 +261,18 @@ class default_menuWidgetContainer extends BaseWidgetContainer
 						$treeHtml .= '<li><span>' . $this->convertToDispString($name) . '</span></li>' . M3_NL;
 						break;
 					case 3:			// セパレータのとき
-						$treeHtml .= '<li><span class="separator">' . $this->convertToDispString($name) . '</span></li>' . M3_NL;
-						
 						// Joomla用メニューデータ作成
-						$addMenuItem = true;			// メニュー項目を追加するかどうか
 						$menuItem->type = 'separator';
 						$menuItem->title = $name;
 						$menuItem->flink = '';
-						$menuItem->parent = false;
+						
+						// ##### Joomla用メニュー階層更新 #####
+						$this->menuTree[] = $menuItem;
+						
+						// ##### タグ作成 #####
+						$treeHtml .= '<li><span class="separator">' . $this->convertToDispString($name) . '</span></li>' . M3_NL;
 						break;
 				}
-				$index++;		// インデックス番号更新
 				
 				if ($this->templateType == 0){			// Joomla!v1.0のとき
 					$itemRow = array(
@@ -261,8 +284,13 @@ class default_menuWidgetContainer extends BaseWidgetContainer
 					$this->tmpl->addVars('itemlist', $itemRow);
 					$this->tmpl->parseTemplate('itemlist', 'a');
 				}
-				// Joomla用メニュー階層
-				if ($addMenuItem) $this->menuTree[] = $menuItem;
+				$menuTreeCount = count($this->menuTree);
+				if ($menuTreeCount > 0){		// 前データがあるときは取得
+					$menuLastItem = $this->menuTree[$menuTreeCount -1];
+					$menuLastItem->deeper = (1 > $menuLastItem->level);
+					$menuLastItem->shallower = (1 < $menuLastItem->level);
+					$menuLastItem->level_diff = $menuLastItem->level - 1;
+				}
 			}
 		}
 		return $treeHtml;
